@@ -96,7 +96,7 @@ mutable struct Optimizer <: MOI.AbstractOptimizer
     bound_sol_pool::Dict{Any,Any}                        # A pool of solutions from solving model_mip
 
     # Linking constraints info for Multilinear terms
-    linking_constraints_info::Union{Nothing,Dict{Any,Any}}     # Stored multilinear linking constraints info 
+    linking_constraints_info::Union{Nothing,Dict{Any,Any}}     # Stored multilinear linking constraints info
 
     # Logging information and status
     logs::Dict{Symbol,Any}                          # Logging information
@@ -108,7 +108,7 @@ mutable struct Optimizer <: MOI.AbstractOptimizer
     # Constructor for Alpine.Optimizer
     function Optimizer()
         m = new()
-        m.options = Alp.get_default_options()
+        m.options = get_default_options()
         MOI.empty!(m)
         return m
     end
@@ -254,10 +254,10 @@ MOI.get(::Optimizer, ::MOI.SolverName) = "Alpine"
 MOI.get(::Optimizer, ::MOI.SolverVersion) = _ALPINE_VERSION
 
 function MOI.set(model::Optimizer, param::MOI.RawOptimizerAttribute, value)
-    return Alp.set_option(model, Symbol(param.name), value)
+    return set_option(model, Symbol(param.name), value)
 end
 function MOI.get(model::Optimizer, param::MOI.RawOptimizerAttribute)
-    return Alp.get_option(model, Symbol(param.name))
+    return get_option(model, Symbol(param.name))
 end
 
 function MOI.add_variables(model::Optimizer, n::Int)
@@ -322,18 +322,6 @@ function MOI.add_constraint(model::Optimizer, vi::MOI.VariableIndex, set::SCALAR
     return MOI.ConstraintIndex{typeof(vi),typeof(set)}(vi.value)
 end
 
-function MOI.supports_constraint(
-    ::Optimizer,
-    ::Type{MOI.VariableIndex},
-    ::Type{MOI.Integer},
-)
-    return true
-end
-
-function MOI.add_constraint(model::Optimizer, f::MOI.VariableIndex, set::MOI.Integer)
-    model.var_type_orig[f.value] = :Int
-    return MOI.ConstraintIndex{typeof(f),typeof(set)}(f.value)
-end
 function MOI.supports_constraint(
     ::Optimizer,
     ::Type{MOI.VariableIndex},
@@ -395,10 +383,10 @@ is_max_sense(model::Optimizer) = model.sense_orig == MOI.MAX_SENSE
 
 function MOI.set(model::Optimizer, ::MOI.ObjectiveSense, sense)
     model.sense_orig = sense
-    if Alp.is_max_sense(model)
+    if is_max_sense(model)
         model.best_obj = -Inf
         model.best_bound = Inf
-    elseif Alp.is_min_sense(model)
+    elseif is_min_sense(model)
         model.best_obj = Inf
         model.best_bound = -Inf
     else
@@ -457,6 +445,32 @@ function MOI.is_valid(model::Alpine.Optimizer, vi::MOI.VariableIndex)
     return 1 <= vi.value <= model.num_var_orig
 end
 
+function _get_bound_set(model::Alpine.Optimizer, vi::MOI.VariableIndex)
+    if !MOI.is_valid(model, vi)
+        throw(MOI.InvalidIndex(vi))
+    end
+    return _bound_set(model.l_var_orig[vi.value], model.u_var_orig[vi.value])
+end
+
+function MOI.is_valid(
+    model::Alpine.Optimizer,
+    ci::MOI.ConstraintIndex{MOI.VariableIndex,S},
+) where {S<:SCALAR_SET}
+    set = _get_bound_set(model, MOI.VariableIndex(ci.value))
+    return set isa S
+end
+
+function MOI.get(
+    model::Alpine.Optimizer,
+    ::MOI.ConstraintSet,
+    ci::MOI.ConstraintIndex{MOI.VariableIndex,S},
+) where {S<:SCALAR_SET}
+    if !MOI.is_valid(model, ci)
+        throw(MOI.InvalidIndex(ci))
+    end
+    return _get_bound_set(model, MOI.VariableIndex(ci.value))
+end
+
 # Taken from MatrixOptInterface.jl
 @enum ConstraintSense EQUAL_TO GREATER_THAN LESS_THAN INTERVAL
 _sense(::Type{<:MOI.EqualTo}) = EQUAL_TO
