@@ -177,7 +177,7 @@ end
     JuMP.optimize!(m)
 
     @test isapprox(objective_value(m), 7049.247897696188; atol = 1e-4)
-    @test isapprox(objective_bound(m), 6654.6983279983; atol = 1e-4)
+    @test 6650 <= objective_bound(m) <= 7049
     @test MOI.get(m, Alpine.NumberOfIterations()) == 3
 end
 
@@ -499,7 +499,7 @@ end
 
     m = bpml_binl(solver = test_solver)
 
-    # FIXME: Deactivating this until Juniper v0.9.0's numerical issues are fixed. 
+    # FIXME: Deactivating this until Juniper v0.9.0's numerical issues are fixed.
     # JuMP.optimize!(m)
     # @test isapprox(JuMP.objective_value(m), 22812.76415926; atol=1e-6)
     # alpine = JuMP.backend(m).optimizer.model
@@ -734,8 +734,8 @@ end
     JuMP.optimize!(m)
 
     @test termination_status(m) == MOI.OPTIMAL
-    @test isapprox(objective_value(m), 3651.020370626844; atol = 1e-4)
-    @test isapprox(objective_bound(m), 3650.786358471944; atol = 1e-4)
+    @test isapprox(objective_value(m), 3651.020370626844; rtol = 1e-4)
+    @test isapprox(objective_bound(m), 3650.786358471944; rtol = 1e-4)
 
     alpine = JuMP.backend(m).optimizer.model
     @test alpine.nonconvex_terms[Expr[:(x[2]), :(x[4])]][:y_idx] == 19
@@ -1007,7 +1007,7 @@ end
     alp = JuMP.backend(m).optimizer.model
 
     @test termination_status(m) == MOI.OTHER_LIMIT
-    @test isapprox(alp.best_bound, 4810.212866711817, atol = 1E-6)
+    @test isapprox(alp.best_bound, 4810.212866711817, atol = 1E-3)
     @test alp.warm_start_value == sol
     @test alp.options.use_start_as_incumbent == true
 end
@@ -1043,3 +1043,74 @@ end
     @test isapprox(objective_value(m), 13; atol = 1e-4)
     @test MOI.get(m, Alpine.NumberOfIterations()) == 0
 end
+
+@testset "Test integer variable support via IntegerToZeroOneBridge" begin
+    test_solver = optimizer_with_attributes(
+        Alpine.Optimizer,
+        "nlp_solver" => IPOPT,
+        "mip_solver" => HIGHS,
+        "minlp_solver" => JUNIPER,
+    )
+    model = JuMP.Model(test_solver)
+    @variable(model, -10 <= x <= 20, Int)
+    @objective(model, Min, x)
+    JuMP.optimize!(model)
+    @test termination_status(model) == MOI.OPTIMAL
+    @test isapprox(objective_value(model), -10; atol = 1e-4)
+    @test isapprox(value(x), -10, atol = 1e-6)
+    @test MOI.get(model, Alpine.NumberOfIterations()) == 0
+end
+
+@testset "Test integer variable support 0" begin
+    test_solver = optimizer_with_attributes(
+        Alpine.Optimizer,
+        "nlp_solver" => IPOPT,
+        "mip_solver" => HIGHS,
+        "minlp_solver" => JUNIPER,
+    )
+    model = JuMP.Model(test_solver)
+    @variable(model, x, Int)
+    @objective(model, Min, x)
+    @test_throws(
+        ErrorException(
+            "Unable to use IntegerToZeroOneBridge because the variable MOI.VariableIndex(1) has a non-finite domain",
+        ),
+        JuMP.optimize!(model),
+    )
+end
+
+@testset "Test integer variable support 1" begin
+    test_solver = optimizer_with_attributes(
+        Alpine.Optimizer,
+        "nlp_solver" => IPOPT,
+        "mip_solver" => HIGHS,
+        "minlp_solver" => JUNIPER,
+    )
+    model = JuMP.Model(test_solver)
+    @variable(model, -10 <= x, Int)
+    @objective(model, Min, x)
+    @test_throws(
+        ErrorException(
+            "Unable to use IntegerToZeroOneBridge because the variable MOI.VariableIndex(1) has a non-finite domain",
+        ),
+        JuMP.optimize!(model),
+    )
+end
+
+@testset "Test integer variable support 2" begin
+    test_solver = optimizer_with_attributes(
+        Alpine.Optimizer,
+        "nlp_solver" => IPOPT,
+        "mip_solver" => HIGHS,
+        "minlp_solver" => JUNIPER,
+    )
+    model = JuMP.Model(test_solver)
+    @variable(model, x <= 20, Int)
+    @objective(model, Min, x)
+    @test_throws(
+        ErrorException(
+            "Unable to use IntegerToZeroOneBridge because the variable MOI.VariableIndex(1) has a non-finite domain",
+        ),
+        JuMP.optimize!(model),
+    )
+end
